==> adams-visualstats-0.3.5-sources.jar: adams/gui/visualization/stats/probabilityplot/NormalPlotOptions.java <==
/*
 * NormalPlotOptions.java
 * Copyright (C) 2011 University of Waikato, Hamilton, New Zealand
 */

package adams.gui.visualization.stats.probabilityplot;

import adams.core.option.OptionHandlingObject;

/**
 <!-- globalinfo-start -->
 * Class for setting the options for the normal probability plot
 * <p/>
 <!-- globalinfo-end -->
 *
 <!-- options-start -->
 * Valid options are: <p/>
 *
 * <pre>-D &lt;int&gt; (property: debugLevel)
 * &nbsp;&nbsp;&nbsp;The greater the number the more additional info the scheme may output to
 * &nbsp;&nbsp;&nbsp;the console (0 = off).
 * &nbsp;&nbsp;&nbsp;default: 0
 * &nbsp;&nbsp;&nbsp;minimum: 0
 * </pre>
 *
 * <pre>-regression-line (property: regLine)
 * &nbsp;&nbsp;&nbsp;Display a linear regression line overlay
 * </pre>
 *
 <!-- options-end -->
 *
 * @author msf8
 * @version $Revision: 3270 $
 *
 */
public class NormalPlotOptions
extends OptionHandlingObject{

  /** for serialization */
  private static final long serialVersionUID = -4737656972085433346L;

  /**Whether to display a regression diagonal line */
  protected boolean m_RegLine;

  public String globalInfo() {
    return "Class for setting the options for the normal probability plot";
  }

  public void defineOptions() {
    super.defineOptions();

    //whether to display a regression line
    m_OptionManager.add(
	"regression-line", "regLine", true);
  }

  /**
   * Set whether a regression line should be drawn
   * @param val		True if regression line drawn
   */
  public void setRegLine(boolean val) {
    m_RegLine = val;
  }

  /**
   * Get whether a regression line should be drawn
   * @return
   */
  public boolean getRegLine() {
    return m_RegLine;
  }

  /**
   * Tip text for the regression line property
   * @return			String describing the property
   */
  public String regLineTipText() {
    return "Display a linear regression line overlay";
  }
}

==> adams-visualstats-0.3.13-sources.jar: adams/gui/visualization/stats/probabilityplot/NormalPlotOptions.java <==
/*
 * NormalPlotOptions.java
 * Copyright (C) 2011 University of Waikato, Hamilton, New Zealand
 */

package adams.gui.visualization.stats.probabilityplot;

import adams.core.option.AbstractOptionHandler;

/**
 <!-- globalinfo-start -->
 * Class for setting the options for the normal probability plot
 * <p/>
 <!-- globalinfo-end -->
 *
 <!-- options-start -->
 * Valid options are: <p/>
 *
 * <pre>-D &lt;int&gt; (property: debugLevel)
 * &nbsp;&nbsp;&nbsp;The greater the number the more additional info the scheme may output to
 * &nbsp;&nbsp;&nbsp;the console (0 = off).
 * &nbsp;&nbsp;&nbsp;default: 0
 * &nbsp;&nbsp;&nbsp;minimum: 0
 * </pre>
 *
 * <pre>-regression-line (property: regLine)
 * &nbsp;&nbsp;&nbsp;Display a linear regression line overlay
 * </pre>
 *
 <!-- options-end -->
 *
 * @author msf8
 * @version $Revision: 4397 $
 *
 */
public class NormalPlotOptions
extends AbstractOptionHandler{

  /** for serialization */
  private static final long serialVersionUID = -4737656972085433346L;

  /**Whether to display a regression diagonal line */
  protected boolean m_RegLine;

  public String globalInfo() {
    return "Class for setting the options for the normal probability plot";
  }

  public void defineOptions() {
    super.defineOptions();

    //whether to display a regression line
    m_OptionManager.add(
	"regression-line", "regLine", true);
  }

  /**
   * Set whether a regression line should be drawn
   * @param val		True if regression line drawn
   */
  public void setRegLine(boolean val) {
    m_RegLine = val;
  }

  /**
   * Get whether a regression line should be drawn
   * @return
   */
  public boolean getRegLine() {
    return m_RegLine;
  }

  /**
   * Tip text for the regression line property
   * @return			String describing the property
   */
  public String regLineTipText() {
    return "Display a linear regression line overlay";
  }
}
